import java.awt.*;
import java.awt.image.*;
import java.util.ArrayList;

public class eSquad extends Squad
{
	public pSquad targeted;

	public eSquad(int myx, int myy, int type, BufferedImage image)
	{
		r = Math.PI;
		x = myx;
		y = myy;
		shipType = type;
		shipImage = image;
		initShips();
		super.initVars();
	}

	private void initShips()
	{
		switch(shipType)
		{
			case 1:
				for(int i = 0; i < 9; i++)
				{
					ships.add(new eFighter( (i%3)*20.0 - 20.0, (i/3)*20.0 - 20.0));
				}	
				break;
			case 2:
				for(int i = 0; i < 4; i++)
				{
					ships.add(new eBomber( (i%2)*30.0 - 15.0, (i/2)*30.0 - 15.0));
				}	
				break;
			case 3:
				for(int i = 0; i < 4; i++)
				{
					ships.add(new eElite( (i%2)*30.0 - 15.0, (i/2)*30.0 - 15.0));
				}		
				break;
			case 4:
				ships.add(new eStation(0.0, 0.0));
				break;
			case 5:
				ships.add(new eCannon(0.0, 0.0));
				break;
		}
	}

	public boolean calc(Battle b, int intstep)
	{ 
		double step = (double)intstep;
		double goalx, goaly;
		double distFromTarSq, distFromPsSq;
		double closest = 10000000000.0;
		pSquad closeSquad = targeted;

		if(ships.size() <=0) return true;

		if(targeted == null || targeted.ships.size() <=0) // if the squad isn't valid
		{
			distFromTarSq = 1000000000.0; // will pick a new one
		}
		else
		{
			distFromTarSq = (x-targeted.x)*(x-targeted.x) + (y-targeted.y)*(y-targeted.y);
		}

		for(pSquad ps : b.pSquads) // pick targeted squad
		{
			distFromPsSq = (x-ps.x)*(x-ps.x) + (y-ps.y)*(y-ps.y);
			if(distFromPsSq <= closest) // is it 100 pixels closer than targeted?
			{
				closest = distFromPsSq;
				closeSquad = ps;
			}
		}
		if(closest <= (distFromTarSq - 40000.0))
		{
			distFromTarSq = closest;
			targeted = closeSquad;
		}

		goalx = targeted.x;
		goaly = targeted.y;
		double goalr = Math.atan2( goalx-x, y-goaly);
         
		if(Math.abs(goalr - r) < (turnSpeed * intstep))
			r = goalr;
		else if(Math.abs(goalr - r) <= Math.PI)
			if(r > goalr)
				r-=(turnSpeed * intstep);
			else
				r+=(turnSpeed * intstep);
		else
			if(r > goalr)
				r+=(turnSpeed * intstep);
			else
				r-=(turnSpeed * intstep);

		// MOVE SQUAD
		x += Math.cos(r-(Math.PI/2)) * (speed * intstep);
		y += Math.sin(r-(Math.PI/2)) * (speed * intstep);


		// CHECK SHIPS FOR FIRING AND DEATH
		for(int i = 0; i < ships.size(); i++)
		{
			Ship ship = ships.get(i);
			if(shipType >=4 && ship.calc(b, this, intstep))  //explosion type for capitals
			{
				b.explode(4, (int)(20*ship.explosionPower), x+ship.osx, y+ship.osy, 0.37*ship.explosionPower, (int)(500*ship.explosionPower), r-Math.PI/2, speed);
				ships.remove(i);
				i--;
			}
			else if(ship.calc(b, this, intstep))
			{
				b.explode(1, (int)(10*ship.explosionPower*ship.explosionPower), x+ship.osx, y+ship.osy, 0.5*Math.sqrt(ship.explosionPower), (int)(500*Math.sqrt(ship.explosionPower)), r-Math.PI/2, speed);
				ships.remove(i);
				i--;
			}
		}




		// set angle within bounds
		if(r>Math.PI)
			r-=2.0*Math.PI;
		if(r<-Math.PI)
			r+=2.0*Math.PI;

		return false;
	}

}
