import java.awt.*;
import java.awt.image.*;
import java.util.ArrayList;

public class pSquad extends Squad
{

	public ArrayList<Waypoint> waypoints = new ArrayList<Waypoint>();
	Waypoint currentWpt;
	public boolean selected = false;
	public Color color;
	public Color tColor;
	public double waypointDistance = 0.0;

	public pSquad(int myx, int myy, int type, Color c, BufferedImage image)
	{
		r = 0.0;
		x = myx;
		y = myy;
		shipType = type;
		color = c;
		shipImage = image;
		initShips();
		super.initVars();
		tColor = new Color(color.getRed(),color.getGreen(),color.getBlue(), 64); // translucent but otherwise equal color
		waypointDistance = (speed / turnSpeed) * (speed / turnSpeed);
	}

	private void initShips()
	{
		switch(shipType)
		{
			case 1:
				for(int i = 0; i < 16; i++)
				{
					ships.add(new pScrambler( (i%4)*15.0 - 22.5, (i/4)*15.0 - 22.5));
				}				
				break;
			case 2:
				for(int i = 0; i < 9; i++)
				{
					ships.add(new pFighter( (i%3)*20.0 - 20.0, (i/3)*20.0 - 20.0));
				}	
				break;
			case 3:
				for(int i = 0; i < 4; i++)
				{
					ships.add(new pBomber( (i%2)*20.0 - 10.0, (i/2)*20.0 - 10.0));
				}	
				break;
			case 4:
				for(int i = 0; i < 4; i++)
				{
					ships.add(new pResilient( (i%2)*30.0 - 15.0, (i/2)*30.0 - 15.0));
				}	
				break;
			case 5:
				ships.add(new pAsp(0.0, 0.0));
				break;
		}
	}

	public boolean calc(Battle b, int intstep)
	{ 
		double step = (double)intstep;
		double goalx, goaly;
		
		if(ships.size() <=0) return true;

		// SQUAD ROTATION
		Waypoint wpt;
		try // get current waypoint
		{
			wpt = waypoints.get(0); 
			goalx = wpt.x;
			goaly = wpt.y;

			// have we reached it?
			if( ((x-goalx)*(x-goalx) + (y-goaly)*(y-goaly)) <= waypointDistance) // if within 60 pixels (too much? eh)
			{
				waypoints.remove(0);
			}
		}
		catch(Exception ex) // or circle endlessly
		{
			goalx = x + Math.cos(r);
			goaly = y + Math.sin(r);
		}

		double goalr = Math.atan2( goalx-x, y-goaly);
         
		if(Math.abs(goalr - r) < (turnSpeed * intstep))
			r = goalr;
		else if(Math.abs(goalr - r) <= Math.PI)
			if(r > goalr)
				r-=(turnSpeed * intstep);
			else
				r+=(turnSpeed * intstep);
		else
			if(r > goalr)
				r+=(turnSpeed * intstep);
			else
				r-=(turnSpeed * intstep);

		// MOVE SQUAD
		x += Math.cos(r-(Math.PI/2)) * (speed * intstep);
		y += Math.sin(r-(Math.PI/2)) * (speed * intstep);


		// CHECK SHIPS FOR FIRING AND DEATH
		for(int i = 0; i < ships.size(); i++)
		{
			Ship ship = ships.get(i);
			if(ship.calc(b, this, intstep))
			{
				b.explode(0, (int)(10*ship.explosionPower*ship.explosionPower), x+ship.osx, y+ship.osy, 0.5*Math.sqrt(ship.explosionPower), (int)(1000*Math.sqrt(ship.explosionPower)), r-Math.PI/2, speed);
				ships.remove(i);
				i--;
			}
		}




		// set angle within bounds
		if(r>Math.PI)
			r-=2.0*Math.PI;
		if(r<-Math.PI)
			r+=2.0*Math.PI;

		return false;
	}

}

